<?php

namespace Forms\Leave\Policies;

use Litepie\User\Contracts\UserPolicy;
use Forms\Leave\Models\Leave;

class LeavePolicy
{

    /**
     * Determine if the given user can view the leave.
     *
     * @param UserPolicy $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function view(UserPolicy $user, Leave $leave)
    {
        if ($user->canDo('leave.leave.view') && $user->isAdmin()) {
            return true;
        }

        return $leave->user_id == user_id() && $leave->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leave.
     *
     * @param UserPolicy $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leave.leave.create');
    }

    /**
     * Determine if the given user can update the given leave.
     *
     * @param UserPolicy $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function update(UserPolicy $user, Leave $leave)
    {
        if ($user->canDo('leave.leave.edit') && $user->isAdmin()) {
            return true;
        }

        return $leave->user_id == user_id() && $leave->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leave.
     *
     * @param UserPolicy $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Leave $leave)
    {
        return $leave->user_id == user_id() && $leave->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leave.
     *
     * @param UserPolicy $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Leave $leave)
    {
        if ($user->canDo('leave.leave.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leave.
     *
     * @param UserPolicy $user
     * @param Leave $leave
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Leave $leave)
    {
        if ($user->canDo('leave.leave.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
